
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.5.post1',
    'branch_nick': 'hotifx-1.23.5.post1',
    'revision_id': 'e01474c2d13b7bb6f0ce49c74dfdb8b2367923a7',
    'revno': 10006
}
